@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -92,7 +92,7 @@ __all__ = ("GlueDataBrewClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -109,7 +109,7 @@ class Exceptions:
 
 class GlueDataBrewClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html)
     """
 
@@ -122,12 +122,12 @@ class GlueDataBrewClient(BaseClient):
         """
 
     def batch_delete_recipe_version(
-        self, *, Name: str, RecipeVersions: List[str]
+        self, *, Name: str, RecipeVersions: Sequence[str]
     ) -> BatchDeleteRecipeVersionResponseTypeDef:
         """
         Deletes one or more versions of a recipe at a time.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.batch_delete_recipe_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.batch_delete_recipe_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#batch_delete_recipe_version)
         """
 
@@ -135,7 +135,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#can_paginate)
         """
 
@@ -147,12 +147,12 @@ class GlueDataBrewClient(BaseClient):
         Format: InputFormatType = None,
         FormatOptions: "FormatOptionsTypeDef" = None,
         PathOptions: "PathOptionsTypeDef" = None,
-        Tags: Dict[str, str] = None
+        Tags: Mapping[str, str] = None
     ) -> CreateDatasetResponseTypeDef:
         """
         Creates a new DataBrew dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.create_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.create_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_dataset)
         """
 
@@ -169,14 +169,14 @@ class GlueDataBrewClient(BaseClient):
         MaxCapacity: int = None,
         MaxRetries: int = None,
         Configuration: "ProfileConfigurationTypeDef" = None,
-        Tags: Dict[str, str] = None,
+        Tags: Mapping[str, str] = None,
         Timeout: int = None,
         JobSample: "JobSampleTypeDef" = None
     ) -> CreateProfileJobResponseTypeDef:
         """
         Creates a new job to analyze a dataset and create its data profile.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.create_profile_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.create_profile_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_profile_job)
         """
 
@@ -188,12 +188,12 @@ class GlueDataBrewClient(BaseClient):
         RecipeName: str,
         RoleArn: str,
         Sample: "SampleTypeDef" = None,
-        Tags: Dict[str, str] = None
+        Tags: Mapping[str, str] = None
     ) -> CreateProjectResponseTypeDef:
         """
         Creates a new DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.create_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.create_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_project)
         """
 
@@ -201,14 +201,14 @@ class GlueDataBrewClient(BaseClient):
         self,
         *,
         Name: str,
-        Steps: List["RecipeStepTypeDef"],
+        Steps: Sequence["RecipeStepTypeDef"],
         Description: str = None,
-        Tags: Dict[str, str] = None
+        Tags: Mapping[str, str] = None
     ) -> CreateRecipeResponseTypeDef:
         """
         Creates a new DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.create_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.create_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_recipe)
         """
 
@@ -223,12 +223,12 @@ class GlueDataBrewClient(BaseClient):
         LogSubscription: LogSubscriptionType = None,
         MaxCapacity: int = None,
         MaxRetries: int = None,
-        Outputs: List["OutputTypeDef"] = None,
-        DataCatalogOutputs: List["DataCatalogOutputTypeDef"] = None,
-        DatabaseOutputs: List["DatabaseOutputTypeDef"] = None,
+        Outputs: Sequence["OutputTypeDef"] = None,
+        DataCatalogOutputs: Sequence["DataCatalogOutputTypeDef"] = None,
+        DatabaseOutputs: Sequence["DatabaseOutputTypeDef"] = None,
         ProjectName: str = None,
         RecipeReference: "RecipeReferenceTypeDef" = None,
-        Tags: Dict[str, str] = None,
+        Tags: Mapping[str, str] = None,
         Timeout: int = None
     ) -> CreateRecipeJobResponseTypeDef:
         """
@@ -237,7 +237,7 @@ class GlueDataBrewClient(BaseClient):
         <https://docs.aws.amazon.com/goto/WebAPI/databrew-2017-07-25/CreateRecipeJob>`_
         **Request Syntax** response = client.create_recipe_job( DatasetName...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.create_recipe_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.create_recipe_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_recipe_job)
         """
 
@@ -246,13 +246,13 @@ class GlueDataBrewClient(BaseClient):
         *,
         CronExpression: str,
         Name: str,
-        JobNames: List[str] = None,
-        Tags: Dict[str, str] = None
+        JobNames: Sequence[str] = None,
+        Tags: Mapping[str, str] = None
     ) -> CreateScheduleResponseTypeDef:
         """
         Creates a new schedule for one or more DataBrew jobs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.create_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.create_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#create_schedule)
         """
 
@@ -260,7 +260,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes a dataset from DataBrew.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.delete_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.delete_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_dataset)
         """
 
@@ -268,7 +268,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes the specified DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.delete_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.delete_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_job)
         """
 
@@ -276,7 +276,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes an existing DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.delete_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.delete_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_project)
         """
 
@@ -286,7 +286,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes a single version of a DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.delete_recipe_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.delete_recipe_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_recipe_version)
         """
 
@@ -294,7 +294,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Deletes the specified DataBrew schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.delete_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.delete_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#delete_schedule)
         """
 
@@ -302,7 +302,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.describe_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.describe_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_dataset)
         """
 
@@ -310,7 +310,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.describe_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.describe_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_job)
         """
 
@@ -318,7 +318,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Represents one run of a DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.describe_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.describe_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_job_run)
         """
 
@@ -326,7 +326,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.describe_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.describe_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_project)
         """
 
@@ -337,7 +337,7 @@ class GlueDataBrewClient(BaseClient):
         Returns the definition of a specific DataBrew recipe corresponding to a
         particular version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.describe_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.describe_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_recipe)
         """
 
@@ -345,21 +345,21 @@ class GlueDataBrewClient(BaseClient):
         """
         Returns the definition of a specific DataBrew schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.describe_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.describe_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#describe_schedule)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#generate_presigned_url)
         """
 
@@ -369,7 +369,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the DataBrew datasets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.list_datasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.list_datasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_datasets)
         """
 
@@ -379,7 +379,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the previous runs of a particular DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.list_job_runs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.list_job_runs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_job_runs)
         """
 
@@ -394,7 +394,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the DataBrew jobs that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.list_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.list_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_jobs)
         """
 
@@ -404,7 +404,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the DataBrew projects that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.list_projects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.list_projects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_projects)
         """
 
@@ -415,7 +415,7 @@ class GlueDataBrewClient(BaseClient):
         Lists the versions of a particular DataBrew recipe, except for `LATEST_WORKING`
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.list_recipe_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.list_recipe_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_recipe_versions)
         """
 
@@ -425,7 +425,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all of the DataBrew recipes that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.list_recipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.list_recipes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_recipes)
         """
 
@@ -435,7 +435,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists the DataBrew schedules that are defined.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.list_schedules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.list_schedules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_schedules)
         """
 
@@ -443,7 +443,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Lists all the tags for a DataBrew resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#list_tags_for_resource)
         """
 
@@ -451,7 +451,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Publishes a new version of a DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.publish_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.publish_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#publish_recipe)
         """
 
@@ -469,7 +469,7 @@ class GlueDataBrewClient(BaseClient):
         Performs a recipe step within an interactive DataBrew session that's currently
         open.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.send_project_session_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.send_project_session_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#send_project_session_action)
         """
 
@@ -477,7 +477,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Runs a DataBrew job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.start_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.start_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#start_job_run)
         """
 
@@ -488,7 +488,7 @@ class GlueDataBrewClient(BaseClient):
         Creates an interactive session, enabling you to manipulate data in a DataBrew
         project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.start_project_session)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.start_project_session)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#start_project_session)
         """
 
@@ -496,24 +496,24 @@ class GlueDataBrewClient(BaseClient):
         """
         Stops a particular run of a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.stop_job_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.stop_job_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#stop_job_run)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceArn: str, Tags: Mapping[str, str]) -> Dict[str, Any]:
         """
         Adds metadata tags to a DataBrew resource, such as a dataset, project, recipe,
         job, or schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, ResourceArn: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes metadata tags from a DataBrew resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#untag_resource)
         """
 
@@ -529,7 +529,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Modifies the definition of an existing DataBrew dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.update_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.update_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_dataset)
         """
 
@@ -551,7 +551,7 @@ class GlueDataBrewClient(BaseClient):
         """
         Modifies the definition of an existing profile job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.update_profile_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.update_profile_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_profile_job)
         """
 
@@ -561,17 +561,17 @@ class GlueDataBrewClient(BaseClient):
         """
         Modifies the definition of an existing DataBrew project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.update_project)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.update_project)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_project)
         """
 
     def update_recipe(
-        self, *, Name: str, Description: str = None, Steps: List["RecipeStepTypeDef"] = None
+        self, *, Name: str, Description: str = None, Steps: Sequence["RecipeStepTypeDef"] = None
     ) -> UpdateRecipeResponseTypeDef:
         """
         Modifies the definition of the `LATEST_WORKING` version of a DataBrew recipe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.update_recipe)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.update_recipe)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_recipe)
         """
 
@@ -585,53 +585,53 @@ class GlueDataBrewClient(BaseClient):
         LogSubscription: LogSubscriptionType = None,
         MaxCapacity: int = None,
         MaxRetries: int = None,
-        Outputs: List["OutputTypeDef"] = None,
-        DataCatalogOutputs: List["DataCatalogOutputTypeDef"] = None,
-        DatabaseOutputs: List["DatabaseOutputTypeDef"] = None,
+        Outputs: Sequence["OutputTypeDef"] = None,
+        DataCatalogOutputs: Sequence["DataCatalogOutputTypeDef"] = None,
+        DatabaseOutputs: Sequence["DatabaseOutputTypeDef"] = None,
         Timeout: int = None
     ) -> UpdateRecipeJobResponseTypeDef:
         """
         Modifies the definition of an existing DataBrew recipe job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.update_recipe_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.update_recipe_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_recipe_job)
         """
 
     def update_schedule(
-        self, *, CronExpression: str, Name: str, JobNames: List[str] = None
+        self, *, CronExpression: str, Name: str, JobNames: Sequence[str] = None
     ) -> UpdateScheduleResponseTypeDef:
         """
         Modifies the definition of an existing DataBrew schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Client.update_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Client.update_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/client.html#update_schedule)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datasets"]) -> ListDatasetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listdatasetspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_job_runs"]) -> ListJobRunsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listjobrunspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listjobspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_projects"]) -> ListProjectsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listprojectspaginator)
         """
 
@@ -640,20 +640,20 @@ class GlueDataBrewClient(BaseClient):
         self, operation_name: Literal["list_recipe_versions"]
     ) -> ListRecipeVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrecipeversionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_recipes"]) -> ListRecipesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrecipespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_schedules"]) -> ListSchedulesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listschedulespaginator)
         """
